#ifndef RCLOCK_H
#define RCLOCK_H

#include <qwidget.h>
#include <qdatetime.h>
#include <qtimer.h>
#include <qevent.h>
#include <rnamespace.h>

/**
 * @short A wall time clock display with date and day of the week
 * @author Fred Gleason <fredg@wava.com>
 *
 * This class implements a clock that displays the current wall clock time,
 * along with the current date and day of the week.
 **/
class RClock : public QWidget
{
  Q_OBJECT
  public:
  /**
   * Instantiates the widget
   **/
   RClock(QWidget *parent=0,const char *name=0);

  /**
   * Returns the suggested size of the widget
   **/
   QSize sizeHint() const;

  /**
   * Returns the sizing policy of the widget
   **/
   QSizePolicy sizePolicy() const;

   /**
    * Sets the widget to display or hide the date/day of week
    * @param state true = Display date, false = Don't display date
    **/
   void setDateDisplay(bool state);

  /**
   * Set 12 hour display mode
   **/
   void set12Hour();

  /**
   * Set 24 hour (military) display mode
   **/
   void set24Hour();
  
  protected:
   void mouseDoubleClickEvent(QMouseEvent *);

  private slots:
    void tickClock();

  private:
    QTime previous_time,current_time;
    QDate previous_date,current_date;
    int time_style;
    char date[40],day[20];
    int date_x,day_x;
    bool show_date;
};

#endif
