/*   rlineedit.h
 *
 *   An flashing button widget.
 *
 *   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef RLINEEDIT_H
#define RLINEEDIT_H

#include <qwidget.h>
#include <qlineedit.h>
#include <qpixmap.h>
#include <qcolor.h>
#include <rnamespace.h>

/**
 * @short A Line Editor with ESC key detection.
 * @author Fred Gleason <fredg@wava.com
 * 
 * This class implements a standard QLineEdit, with the addition of 
 * a 'escapePressed()' signal.
 **/
class RLineEdit : public QLineEdit
{
  Q_OBJECT

  public:
  /**
   * Instantiates the widget.
   * @param parent The parent widget.
   * @param name The name of the widget.
   **/
   RLineEdit(QWidget *parent,const char *name);

  /**
   * Instantiates the widget.
   * @param parent The parent widget.
   * @param name The name of the widget.
   * @param contents Contents of the widget.
   **/
   RLineEdit(const QString &contents,QWidget *parent,const char *name);

  signals:
   void escapePressed();

  protected:
   void keyPressEvent(QKeyEvent *e);
};



#endif
