#ifndef RSEGCLOCK_H
#define RSEGCLOCK_H

#include <qwidget.h>
#include <qdatetime.h>
#include <qtimer.h>
#include <rnamespace.h>

#include <rnamespace.h>
#include <rseglist.h>

//
// Fonts
//
#define RSEGCLOCK_TITLE_FONT_FACE "Helvetica"
#define RSEGCLOCK_TITLE_FONT_SIZE 20
#define RSEGCLOCK_TITLE_FONT_WEIGHT QFont::Normal

#define RSEGCLOCK_DIGIT_FONT_FACE "Helvetica"
#define RSEGCLOCK_DIGIT_FONT_SIZE 36
#define RSEGCLOCK_DIGIT_FONT_WEIGHT QFont::Normal

#define RSEGCLOCK_LABEL_FONT_FACE "System"
#define RSEGCLOCK_LABEL_FONT_SIZE 16
#define RSEGCLOCK_LABEL_FONT_WEIGHT QFont::Normal


/**
 * @short Displays a broadcast segment clock and countdown timer.
 * @author Fred Gleason <fredg@wava.com>
 *
 * This class implements a widget to display wall clock time and a countdown
 * timer.  The countdown timer operates on segment data supplied in a 
 * @ref RSegList object.  Each time segment can have a text label associated
 * with it, which is displayed at the bottom of the widget.
 * @see RSegList
 **/

class RSegClock : public QWidget
{
  Q_OBJECT
  public:
  enum Orientation {Horizontal=0,Vertical=1};

  /**
   * Instantiates the widget.
   * @param layout Indicates layout style of the widget.  SEG_HORIZ gives
   * a horizontal layout (clock and timer side-by-side), and SEG_VERT give
   * a vertical layout (the clock stacked above the timer).
   **/
    RSegClock(Qt::Orientation layout,QWidget *parent=0,
	      const char *name=0);
    QSizePolicy sizePolicy() const;

  /**
   * Load a segment list.  
   **/     
    void loadSegList(struct RSegList *list);

  /**
   * Set the time display to be in twelve hour mode.
   **/
    void set12Hour();

  /**
   * Set the time display to be in twenty-four hour (military) style.
   **/
    void set24Hour();

  /**
   * Set the time offset.
   * @param secs Time offset in seconds.
   **/
    void setOffset(int secs);

  private slots:
    void tickClock();

  signals:
  /**
   * Indicates that the indexed segment entry has started counting down.
   **/
    void segStarted(int);
  /**
   * Indicates that the indexed segment entry has finished counting down.
   **/
    void segFinished(int);

  protected:
    void paintEvent(QPaintEvent *);

  private:
    int clock_x,clock_y;
    int clock_size_x;
    int clock_size_y; 
    int segment_x,segment_y;
    int segment_size_x;
    int segment_size_y; 
    int label_x,label_y;
    QTime current_time,previous_time;
    RSegList *rseglist;
    int current_index;
    int time_style;
    int time_offset;
    QFont title_font;
    QFont digit_font;
    QFont label_font;
};

#endif
