/*   rsocket.h
 *
 *   A QSocket object with connection-ID.
 *
 *   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef RSOCKET_H
#define RSOCKET_H

#include <qobject.h>
#include <qsocket.h>
#include <rnamespace.h>


/**
 * @short A QSocket object with connection-ID. 
 * @author Fred Gleason <fredg@wava.com>
 *
 * RSocket is a QSocket-like object that also features signals that allow
 * particular connections to be IDed.
 **/
class RSocket : public QSocket
{
  Q_OBJECT

  public:
  /**
   * Create a RSocket with the following parameters:
   * @param parent The parent object
   * @param name The name of the Object
   **/
   RSocket(int id,QObject *parent,const char *name);

  signals:
   void hostFoundID(int id);
   void connectedID(int id);
   void connectionClosedID(int id);
   void delayedCloseFinishedID(int id);
   void readyReadID(int id);
   void bytesWrittenID(int nbytes,int id);
   void errorID(int error,int id);

  private slots:
   void hostFoundData();
   void connectedData();
   void connectionClosedData();
   void delayedCloseFinishedData();
   void readyReadData();
   void bytesWrittenData(int nbytes);
   void errorData(int error);

  private:
   int id_num;
};



#endif
