/*   rsoundselector.h
 *
 *   A selection widget for audio devices.
 *
 *   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef RSOUNDSELECTOR_H
#define RSOUNDSELECTOR_H

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <qobject.h>
#include <qwidget.h>
#include <qstring.h>
#include <qdatetime.h>
#include <qtimer.h>
#include <qlistbox.h>
#include <rwavefile.h>
#include <rnamespace.h>
#include <rsoundcard.h>

#ifdef HPI
#include <hpi/hpi.h>
#endif

#ifdef ALSA
#include <alsa/asoundlib.h>
#endif

/**
 * @short A selector box for sound card resources.
 * @author Fred Gleason <fredg@wava.com>
 *
 * RSoundSelector implements a ListBox showing the available Input
 * or Output channels on a sound card.  It automatically displays all
 * such resources found by RSoundCard, and will emit signals to determine
 * the users selection of one.
 **/
class RSoundSelector : public QListBox
{
  Q_OBJECT

  public:
  /**
   * Create a RSoundSelector for either an Input or Output device class.
   * @param hpi_handle HPI subsystem handle.
   * @param dev_class The device class.
   * @param parent The parent widget.
   * @param name The name of the widget.
   **/
   RSoundSelector(RSoundCard::DeviceClass dev_class,
		  QWidget *parent=0,const char *name=0);

  signals:

  /**
   * Emitted whenever the selection is changed.
   * @param card The new card selection.
   * @param stream The new stream selection.
   **/
   void changed(int card,int stream);

  /**
   * Emitted whenever the selection is changed.
   * @param card The new card selection.
   **/
   void card(int card);

  /**
   * Emitted whenever the selection is changed.
   * @param stream The new stream selection.
   **/
   void stream(int stream);

#ifdef HPI
  private slots:
   void selection(int selection);

  private:
   RSoundCard *sound_card;
#endif  // HPI

#ifdef ALSA
  private slots:
   void selection(int selection);

  private:
   RSoundCard *sound_card;
#endif  // ALSA
};


#endif  // RSOUNDSELECTOR_H
