// rteloscaller.h
//
// Call Data Container Class
//
//   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as
//   published by the Free Software Foundation; either version 2 of
//   the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef RTELOSCALLER_H
#define RTELOSCALLER_H

#include <qstring.h>

/**
 * @short A container class for Telos caller data.
 *
 * This class is used to hold the specific caller data in a manner compatible
 * with the caller data commands in RTelosTwoX12.
 *
 * @author Fred Gleason <fredg@wava.com>
 **/
class RTelosCaller
{
  public:

  /**
   * Create a RTelosCaller object.
   **/
   RTelosCaller();

  /**
   * Clear the contents.
   **/
   void clear();

  /**
   * Generate a buffer suitable for sending with the 
   * RTelosTwoX12::SendCallerData command.
   *
   * @param buffer Pointer to buffer to which the data should be written.
   * @param size Size of buffer.  This will be changed to the actual size 
   * of the data written into buffer.
   *
   * Returns True = buffer write successful, false = buffer too small.
   **/ 
   bool getBuffer(char *buffer,unsigned *size);

  /**
   * Fill RTelosCaller instance using a buffer obtained from a 
   * RTelosTwoX12::ReturnCallerData command.
   * @param buffer Pointer to buffer containing the data.
   * @param size Size of the data.
   * @param preserve True = Don't clear fields that are empty, false = do.
   *
   * Returns True = Buffer load successful, false = formatting error
   **/
   bool setBuffer(char *buffer,unsigned size,bool preserve=true);

  /**
   * Get the Origin ID field
   *
   * Returns Value of Origin ID field.
   **/
   QString originId() const;

  /**
   * Set the Origin ID field
   * @param id = Value to set Origin ID to.
   **/
   void setOriginId(QString id);

  /**
   * Get the Name field
   *
   * Returns Value of Name field.
   **/
   QString name() const;

  /**
   * Set the Name field
   * @param name = Value to set Name to.
   **/
   void setName(QString name);

  /**
   * Get the Street field
   *
   * Returns Value of Street field.
   **/
   QString street() const;

  /**
   * Set the Street field
   * @param street = Value to set Street to.
   **/
   void setStreet(QString street);

  /**
   * Get the City field
   *
   * Returns Value of City field.
   **/
   QString city() const;

  /**
   * Set the City field
   * @param city = Value to set City to.
   **/
   void setCity(QString city);

  /**
   * Get the State field
   *
   * Returns Value of State field.
   **/
   QString state() const;

  /**
   * Set the State field
   * @param state = Value to set State to.
   **/
   void setState(QString state);

  /**
   * Get the ZIP Code field
   *
   * Returns Value of ZIP Code field.
   **/
   QString zip() const;

  /**
   * Set the ZIP Code field
   * @param zip = Value to set ZIP Code to.
   **/
   void setZip(QString zip);

  /**
   * Get the Phone Number field
   *
   * Returns Value of Phone Number field.
   **/
   QString phone() const;

  /**
   * Set the Phone Number field
   * @param phone = Value to set Phone Number to.
   **/
   void setPhone(QString phone);

  /**
   * Get the Station field
   *
   * Returns Value of Station field.
   **/
   QString station() const;

  /**
   * Set the Station field
   * @param station = Value to set Station to.
   **/
   void setStation(QString station);

  /**
   * Get the Gender field
   *
   * Returns Value of Gender field.
   **/
   QString gender() const;

  /**
   * Set the Gender field
   * @param gender = Value to set Gender to.
   **/
   void setGender(QString gender);

  /**
   * Get the Comment field
   *
   * Returns Value of Comment field.
   **/
   QString comment() const;

  /**
   * Set the Comment field
   * @param comment = Value to set Comment to.
   **/
   void setComment(QString comment);

  /**
   * Get the User field
   *
   * Returns Value of User field.
   **/
   QString user() const;

  /**
   * Set the User field
   * @param user = Value to set User to.
   **/
   void setUser(QString user);

  private:
   QString call_origin_id;
   QString call_name;
   QString call_street;
   QString call_city;
   QString call_state;
   QString call_zip;
   QString call_phone;
   QString call_station;
   QString call_gender;
   QString call_comment;
   QString call_user;
};


#endif
