// rtelosmessage.h
//
// Message Data Container Class
//
//   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as
//   published by the Free Software Foundation; either version 2 of
//   the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public
//   License along with this program; if not, write to the Free Software
//   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#ifndef RTELOSMESSAGE_H
#define RTELOSMESSAGE_H

#include <qstring.h>

/**
 * @short A container class for Telos message data.
 *
 * This class is used to hold the specific message data in a manner compatible
 * with the message data commands in RTelosTwoX12.
 *
 * @author Fred Gleason <fredg@wava.com>
 **/
class RTelosMessage
{
  public:

  /**
   * Create a RTelosMessage object.
   **/
   RTelosMessage();

  /**
   * Clear the contents.
   **/
   void clear();

  /**
   * Generate a buffer suitable for sending with the RTelosTwoX12::MessageIn
   * command.
   * @param buffer Pointer to buffer to which the data should be written.
   * @param size Size of buffer.  This will be changed to the actual size 
   * of the data written into buffer.
   *
   * Returns True = buffer write successful, false = buffer too small.
   **/ 
   bool getBuffer(char *buffer,unsigned *size);

  /**
   * Fill RTelosCaller instance using a buffer obtained from a 
   * RTelosTwoX12::MessageOut command.
   * @param buffer Pointer to buffer containing the data.
   * @param size Size of the data.
   *
   * Returns True = Buffer load successful, false = formatting error
   **/
   bool setBuffer(char *buffer,unsigned size);

  /**
   * Get the ForeColor field
   *
   * Returns Value of Forecolor field.
   **/
   QString foreColor() const;

  /**
   * Set the ForeColor field
   * @param color = Value to set Forecolor to.
   **/
   void setForeColor(QString color);

  /**
   * Get the BackColor field
   *
   * Returns Value of BackColor field.
   **/
   QString backColor() const;

  /**
   * Set the BackColor field
   * @param color = Value to set BackColor to.
   **/
   void setBackColor(QString color);

  /**
   * Get the Sender Name field
   *
   * Returns Value of Sender Name field.
   **/
   QString name() const;

  /**
   * Set the Sender Name field
   * @param name = Value to set Sender Name to.
   **/
   void setName(QString name);

  /**
   * Get the Message field
   *
   * Returns Value of Message field.
   **/
   QString message() const;

  /**
   * Set the Message field
   * @param msg = Value to set Message to.
   **/
   void setMessage(QString msg);

  private:
   QString msg_fore_color;
   QString msg_back_color;
   QString msg_name;
   QString msg_message;
};


#endif
