#ifndef RTHUMBWHEEL_H
#define RTHUMBWHEEL_H

#include <qwidget.h>
#include <qcolor.h>
#include <qpainter.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qbitmap.h>
#include <qpushbutton.h>
#include <rnamespace.h>
#include <rsegmeter.h>

/**
 * @short A small footprint level control with position indicator
 * This class implements a touchscreen-friendly level control with position
 * indicator that takes up less screen real estate than the traditional slider
 * control.
 * @author Fred Gleason <fredg@wava.com>
 **/
class RThumbWheel : public QWidget
{
 Q_OBJECT
 public:

 /**
  * Instantiates the widget.
  **/
  RThumbWheel(QWidget *parent=0,const char *name=0);

 /**
  * Returns a suggested size for the widget
  **/
  QSize sizeHint() const;

  /**
   * Returns the sizing policy for the widget
   **/
  QSizePolicy sizePolicy() const;

  /**
   * Sets the range of the control
   * @param min The minimum value
   * @param max The maximum value
   **/
  void setRange(int min,int max);

  /**
   * Set the increment by which the value will change when the up or down
   * arrow is pushed
   * @param step Increment value
   */
  void setStepSize(int step);

  /**
   * Sets the text of the label associated with the control
   * @param label Text to be associated with the control
   **/
  void setLabel(QString label);

 public slots:

  /**
   * Sets the value of the control
   * @param value Value to set the control to
   **/
  void setValue(int value);

  /**
   * Equivalent to pressing the up arrow
   **/ 
  void stepUp();

  /**
   * Equivalent to pressing the down arrow
   **/ 
  void stepDown();

 signals:

  /**
   * Emitted when then value of the control changes
   * @param value New value of control
   **/
  void valueChanged(int value);

 protected:
  void paintEvent(QPaintEvent *);

 private:
  QPushButton *up_button,*down_button;
  RSegMeter *meter;
  QPixmap *up_arrow,*down_arrow;
  QString widget_label;
  int min_value,max_value,step_size;
  int widget_value;
  int label_x,label_y;
};


#endif
