/*   rtimeengine.h
 *
 *   An event timer engine.
 *
 *   (C) Copyright 2002 Fred Gleason <fredg@wava.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef RTIMEENGINE_H
#define RTIMEENGINE_H

#include <qwidget.h>
#include <qdatetime.h>
#include <qtimer.h>
#include <rnamespace.h>


/**
 * @short A precision event time list engine.
 * @author Fred Gleason <fredg@wava.com>
 *
 * This class implements an "engine" component into which time events can
 * be loaded.  When the time arrives, a signal will be sent.
 **/

class RTimeEngine : public QObject
{
  Q_OBJECT
  public:
  /**
   * Instantiates the object.
   **/
    RTimeEngine(QObject *parent=0,const char *name=0);

  /**
   * Destroys the object
   **/
    ~RTimeEngine();

  /**
   * Clears all events.
   **/
    void clear();

  /**
   * Get an event by id.
   * @param id = The id of the event.
   * Returns: the scheduled time of the event.
   **/
    QTime event(int id) const;

  /**
   * Add a time event.  
   * @param id = The id to be sent by the 'timeout(int)' signal for this event.
   * @param time = The time at which to emit the 'timeout(int)' signal.
   **/     
    void addEvent(int id,QTime time);

  /**
   * Remove a time event.  
   * @param id = The id of the event to be removed.
   **/     
    void removeEvent(int id);

  /**
   * Get the id of the next event.
   * Returns: the id of the next scheduled event.
   **/
    int next() const;

  signals:
  /**
   * Emitted when an event occurs.
   * @param id = The id of the event.
   **/
    void timeout(int id);

  private slots:
    void timerData();

  private:
    void SetTimer();
    QTimer *engine_timer;
    unsigned engine_quantity;
    int *engine_event_id;
    int *engine_event_time;
    int engine_pending_id;
};

#endif
